.. PySCHISM documentation master file, created by
   sphinx-quickstart on Mon Oct 12 09:40:06 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PySCHISM
========

.. warning::
  PySCHISM is a new package. The syntax of classes and methods in the library are subject to change in future releases, which will also significantly optimize performance and speed of some functionalities. As such, updates to PySCHISM may not be backwards compatible.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
